@@ -20,7 +20,7 @@
 #####################       A U T H O R       ##########################
 #                                                                      #
 #   Copyright 2010 Jack Desert                                         #
-#   <jackdesert556@gmail.com>                                          #
+#   <jackdesert@gmail.com>                                          #
 #   <http://www.LetsEATalready.com>                                    #
 #                                                                      #
 ######################      L I C E N S E     ##########################
@@ -141,7 +141,7 @@ from socket import gaierror
 
 def handle_general_error(name_string = '', suggestion_string = ''):
     pr3('\nAn error has occurred. If this error persists, please ')
-    pr3('contact the author at jackdesert556@gmail.com.')
+    pr3('contact the author at jackdesert@gmail.com.')
     pr3('The nutshell version is listed way down below. But here')
     pr3('are the details if you are interested:')
     print(traceback.print_exc())
@@ -241,14 +241,14 @@ def up_images(in_html, wp_client_obj, ELYXER_ENGINE, in_DIR_OFFSET):
         except AssertionError:
             print("There was a problem uploading your image.")
             print("imageSrc should start with http://")
-            print("Please contact the author at jackdesert556@gmail.com")
+            print("Please contact the author at jackdesert@gmail.com")
             handle_general_error()
         try:
             assert(local_image_url in in_html)
         except AssertionError:
             print("There was a problem uploading your image.")
             print("local_image_url not found in in_html")
-            print("Please contact the author at jackdesert556@gmail.com")
+            print("Please contact the author at jackdesert@gmail.com")
             handle_general_error()
         snapshot = in_html
         in_html = in_html.replace(local_image_url, imageSrc)
@@ -257,7 +257,7 @@ def up_images(in_html, wp_client_obj, ELYXER_ENGINE, in_DIR_OFFSET):
         except AssertionError:
             print("There was a problem uploading your image.")
             print("local_image_url not replaced with imageSrc in post")
-            print("Please contact the author at jackdesert556@gmail.com")
+            print("Please contact the author at jackdesert@gmail.com")
             handle_general_error()
 
         img_tag = find_local_image_tag(in_html, ELYXER_ENGINE)
@@ -333,7 +333,7 @@ def new_shell():
         pr3('Running on GNU/Linux')
     else:
         pr3('I\'m not sure what operating system you are running on.')
-        pr3('Please write the author at jackdesert556@gmail.com to report possible bug')
+        pr3('Please write the author at jackdesert@gmail.com to report possible bug')
     # GNU/Linux, Mac, and unidentified OS's call xterm
     return('xterm -T "LyXBlogger" -fg gold -bg black -fn 10x20 -e python %s %s %s ')
 
@@ -549,7 +549,7 @@ def get_html(input_file, CUT_FLAG):
     elif (TITLE_EXPECTED_IN_BODY):
         pass
         #~ pr3 ('\nWARNING! The title of your entry may appear twice.')
-        #~ pr3 ('Please notify the author at jackdesert556@gmail.com to')
+        #~ pr3 ('Please notify the author at jackdesert@gmail.com to')
         #~ pr3 ('have this bug squashed.\n\n Press Enter to continue uploading.')
         #~ sys.stdin.readline()
         # What this really means is an opening title tag was found, but
@@ -569,6 +569,10 @@ def get_html(input_file, CUT_FLAG):
     # Remove Arrows from footnotes and margin notes
     html = html.replace('[→', '[')
     html = html.replace('→]', ']')
+    
+    # Change the elyxer-generated id to a class, since wordpresslib appears to 
+    # strip out all ids upon upload
+    html = html.replace("<div class=\"footer\" id=\"generated-by\">", "<div class=\"footer generated-by-elyxer\">")
 
     return html, blog_title, ELYXER_ENGINE
 
@@ -593,7 +597,7 @@ def get_configpath():
         return "~/.lyxblogger/config.cfg"
     else:
         pr3('I\'m not sure what operating system you are running on.')
-        pr3('Please write the author at jackdesert556@gmail.com to report possible bug')
+        pr3('Please write the author at jackdesert@gmail.com to report possible bug')
         wait_for_consumer()
     # GNU/Linux, Mac, and unidentified OS's call xterm
 
@@ -835,9 +839,9 @@ def main():
     pr3 ('License: GNU GPL3. See <http://www.gnu.org/licenses>\n')
 
     pr3('AUTHOR')
-    pr3('Copyright 2010 Jack Desert')
+    pr3('Copyright 2010, 2011, 2012 Jack Desert')
     pr3('Please send any comments, suggestions, or bug reports')
-    pr3('to jackdesert556@gmail.com')
+    pr3('to jackdesert@gmail.com')
     pr3("Author's personal blog: www.LetsEATalready.com\n")
 
     config = run_init_config()
@@ -887,6 +891,7 @@ def main():
     post.description = html
     # publish post
     pr3 ("\nWORDS\nLet's upload your thoughts")
+    
     filesize = str(os.path.getsize(input_file) / 1024) + ' kB'
     pr3("Uploading xhtml: " + input_file + '.  Size: ' + filesize )
     try:
